@@ -1,7 +1,7 @@
 package Permute::Named::Iter;
 
-our $DATE = '2015-10-01'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-09-25'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -85,7 +85,7 @@ Permute::Named::Iter - Permute multiple-valued key-value pairs
 
 =head1 VERSION
 
-This document describes version 0.02 of Permute::Named::Iter (from Perl distribution Permute-Named-Iter), released on 2015-10-01.
+This document describes version 0.03 of Permute::Named::Iter (from Perl distribution Permute-Named-Iter), released on 2016-09-25.
 
 =head1 SYNOPSIS
 
@@ -144,10 +144,6 @@ C<@p> will just contain the one permutation:
 
  ({bool => 1, x => 'foo'})
 
-=head1 SEE ALSO
-
-L<Permute::Named>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Permute-Named-Iter>.
@@ -164,13 +160,20 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Permute::Named>, L<PERLANCAR::Permute::Named> and CLI <permute-named>.
+
+L<Set::CrossProduct>, L<Set::Product>, et al (see the POD of Set::Product for
+more similar modules) and CLI <cross>.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
